@@ -19,69 +19,17 @@
 
 #include "screenshooter-utils.h"
 
-#include <X11/Xlib.h>
-#include <X11/Xatom.h>
-#include <gdk/gdk.h>
-#include <gdk/gdkx.h>
-#include <cairo-xlib.h>
+#include <glib/gstdio.h>
 #include <libxfce4ui/libxfce4ui.h>
 
-
+#ifdef ENABLE_WAYLAND
+#include <gdk/gdkwayland.h>
+#endif
 
 /* Internals */
 
 
 
-/* Replacement for gdk_screen_get_active_window */
-static Window
-get_active_window_from_xlib (void)
-{
-  GdkDisplay *display;
-  Display *dsp;
-  Atom active_win, type;
-  int status, format;
-  unsigned long n_items, bytes_after;
-  unsigned char *prop;
-  Window window;
-
-  display = gdk_display_get_default ();
-  dsp = gdk_x11_display_get_xdisplay (display);
-
-  active_win = XInternAtom (dsp, "_NET_ACTIVE_WINDOW", True);
-  if (active_win == None)
-    return None;
-
-  gdk_x11_display_error_trap_push (display);
-
-  status = XGetWindowProperty (dsp, DefaultRootWindow (dsp),
-                               active_win, 0, G_MAXLONG, False,
-                               XA_WINDOW, &type, &format, &n_items,
-                               &bytes_after, &prop);
-
-  if (status != Success || type != XA_WINDOW)
-    {
-      if (prop)
-        XFree (prop);
-
-      gdk_x11_display_error_trap_pop_ignored (display);
-      return None;
-    }
-
-  if (gdk_x11_display_error_trap_pop (display) != Success)
-    {
-      if (prop)
-        XFree (prop);
-
-      return None;
-    }
-
-  window = *(Window *)(void*) prop;
-  XFree (prop);
-  return window;
-}
-
-
-
 /**
  * @format - a date format string
  *
@@ -253,6 +201,14 @@ screenshooter_read_rc_file (const gchar *file, ScreenshotData *sd)
   sd->show_in_folder = show_in_folder;
   sd->custom_action_command = last_custom_action_command;
 
+  /* Under Wayland force FULLSCREEN region */
+#ifdef ENABLE_WAYLAND
+  if (GDK_IS_WAYLAND_DISPLAY (gdk_display_get_default ()))
+    {
+      sd->region = FULLSCREEN;
+    }
+#endif
+
   /* Check if the screenshot directory read from the preferences is valid */
   if (G_UNLIKELY (!screenshooter_is_directory_writable (sd->screenshot_dir)))
     {
@@ -436,6 +392,8 @@ void screenshooter_error (const gchar *format, ...)
   message = g_strdup_vprintf (format, va_args);
   va_end (va_args);
 
+  g_fprintf (stderr, "Error: %s\n", message);
+
   dialog = gtk_message_dialog_new (NULL, GTK_DIALOG_MODAL,
                                    GTK_MESSAGE_ERROR, GTK_BUTTONS_OK,
                                    NULL);
@@ -555,83 +513,6 @@ screenshooter_f1_key (GtkWidget *widget, GdkEventKey *event, gpointer user_data)
 
 
 
-/* Replacement for gdk_screen_width/gdk_screen_height */
-void
-screenshooter_get_screen_geometry (GdkRectangle *geometry)
-{
-  GdkRectangle *tmp = xfce_gdk_screen_get_geometry ();
-  geometry->width = tmp->width;
-  geometry->height = tmp->height;
-  g_free (tmp);
-}
-
-
-
-GdkWindow*
-screenshooter_get_active_window (GdkScreen *screen,
-                                 gboolean  *needs_unref,
-                                 gboolean  *border)
-{
-  GdkWindow *window, *window2;
-  Window xwindow;
-  GdkDisplay *display;
-
-  TRACE ("Get the active window");
-
-  display = gdk_display_get_default ();
-  xwindow = get_active_window_from_xlib ();
-  if (xwindow != None)
-    window = gdk_x11_window_foreign_new_for_display (display, xwindow);
-  else
-    window = NULL;
-
-  /* If there is no active window, we fallback to the whole screen. */
-  if (G_UNLIKELY (window == NULL))
-    {
-      TRACE ("No active window, fallback to the root window");
-
-      window = gdk_get_default_root_window ();
-      *needs_unref = FALSE;
-      *border = FALSE;
-    }
-  else if (G_UNLIKELY (gdk_window_is_destroyed (window)))
-    {
-      TRACE ("The active window is destroyed, fallback to the root window.");
-
-      g_object_unref (window);
-      window = gdk_get_default_root_window ();
-      *needs_unref = FALSE;
-      *border = FALSE;
-    }
-  else if (gdk_window_get_type_hint (window) == GDK_WINDOW_TYPE_HINT_DESKTOP)
-    {
-      /* If the active window is the desktop, grab the whole screen */
-      TRACE ("The active window is the desktop, fallback to the root window");
-
-      g_object_unref (window);
-
-      window = gdk_get_default_root_window ();
-      *needs_unref = FALSE;
-      *border = FALSE;
-    }
-  else
-    {
-      /* Else we find the toplevel window to grab the decorations. */
-      TRACE ("Active window is a normal window, grab the toplevel window");
-
-      window2 = gdk_window_get_toplevel (window);
-
-      g_object_unref (window);
-
-      window = window2;
-      *border = TRUE;
-    }
-
-  return window;
-}
-
-
-
 void
 screenshooter_show_file_in_folder (const gchar *save_location)
 {
@@ -728,39 +609,3 @@ screenshooter_restrict_file_permission (GFile *file)
   g_free (path);
   g_object_unref (info);
 }
-
-
-
-/*
- * Replacement for gdk_pixbuf_get_from_window which only takes
- * one (first) correct screenshot per execution.
- * For more details see:
- * https://gitlab.xfce.org/apps/xfce4-screenshooter/-/issues/89
- */
-GdkPixbuf*
-screenshooter_pixbuf_get_from_window (GdkWindow *window,
-                                      gint       src_x,
-                                      gint       src_y,
-                                      gint       width,
-                                      gint       height)
-{
-  gint             scale_factor;
-  cairo_surface_t *surface;
-  GdkPixbuf       *pixbuf;
-
-  scale_factor = gdk_window_get_scale_factor (window);
-  surface = cairo_xlib_surface_create (gdk_x11_display_get_xdisplay (gdk_window_get_display (window)),
-                                       gdk_x11_window_get_xid (window),
-                                       gdk_x11_visual_get_xvisual (gdk_window_get_visual (window)),
-                                       gdk_window_get_width (window) * scale_factor,
-                                       gdk_window_get_height (window) * scale_factor);
-  pixbuf = gdk_pixbuf_get_from_surface (surface,
-                                        src_x * scale_factor,
-                                        src_y * scale_factor,
-                                        width * scale_factor,
-                                        height * scale_factor);
-
-  cairo_surface_destroy (surface);
-
-  return pixbuf;
-}
